#[no_mangle]
pub unsafe extern "C" fn axiolid_v0_4_context_create(
config: *const AxiolidContextConfig,
out_context: *mut AxiolidContextHandle,
) -> AxiolidStatusExpand description
Create and transfer ownership of a context handle to the caller.
Both pointers must refer to readable/writable instances for the duration of this call.
Safety
Every non-null pointer must be aligned and valid for the documented read or write extent.