#[no_mangle]
pub unsafe extern "C" fn axiolid_v0_4_subtract_many(
context: AxiolidContextHandle,
subject: AxiolidMeshHandle,
tools: *const AxiolidMeshHandle,
tool_count: usize,
tolerance_value: AxiolidTolerance,
out_result: *mut AxiolidResultHandle,
) -> AxiolidStatusExpand description
Subtract a borrowed array of mesh handles from one subject mesh.
Safety
Every non-null pointer must be aligned and valid for the documented read or write extent.